%% This script demonstrates over-fitting due to a more complex model (M=9).
 % While training error keeps reducing as model complexity is increased, the
 % testing error jumps when the M=9 model starts capturing noise variations
 % instead of the real data variations.
clf;
lambda=0;

%% training errors as M goes from 0 to 9
load data_10;
E_RMS_train=zeros(10,1);
for m=0:9
    [w{m+1},beta(m+1),E_RMS_train(m+1)]=fit_polynomial_ML(x,t,m,lambda);
end

%% testing error on an independent test set as M goes from 0 to 9
load data_100;
E_RMS_test=zeros(10,1);
for m=0:9
    f=evaluate_polynomial(x,w{m+1});
    E=.5*(sum((f-t).^2)+lambda*sum(w{m+1}.^2));
    E_RMS_test(m+1)=sqrt(2*E/length(x));
end

%% plot results
clf;
plot(0:9,E_RMS_train,'o-','Color','blue','Linewidth',2);
hold on;
plot(0:9,E_RMS_test,'o-','Color','red','Linewidth',2);
xlabel('M');
ylabel('E_{RMS}');
legend Training Testing
axis([-.8 9.8 0 1]);
print(gcf,'Figure_1_5','-dpng');